function result = Mie_rain3(fGHz, TK, nrain, pam, distribution)

% Extinction, scattering, absorption, backscattering and 
% asymmetric scattering coefficients in 1/km versus rain rate, 
% using Mie Theory, and Liebe '91 dielectric model for water.
% Input:
% fGHz: frequency in GHz, TK: temperature in K, 
% nrain: Number of rain rates between Rmin=0.1 and Rmax=100mm/h
% pam: 0 if no costeta data to be given, 1 if they are needed
% distribution='LP' for Laws-Parsons, 'MP' for Marshall-Palmer,
% 'JD' for Joss-Drizzle, or 'JT' for Joss-Thunderstorm
% C. Mtzler, June 2002, revised Oct. 2002.

Rmin=0.1;   
nsteps=551;
m=sqrt(epswater(fGHz, TK));
fact=1000^(1/(nrain-0.99999));
R=Rmin/fact;
nx=(1:nsteps)';
c0=299.793;
for jr = 1:nrain
    R=R*fact;
    dD=0.01*R^(1/6)/fGHz^0.05;
    D=(nx-1)*dD;
    x=pi*D*fGHz/c0;
    sigmag=pi*D.*D/4;
if distribution=='LP'
    NP=rainLP(R,D);
elseif distribution=='MP'
    NP=rainMP(R,D);
elseif distribution=='JD'
    NP=rainJD(R,D);
elseif distribution=='JT'
    NP=rainJT(R,D);
end;
    sn=sigmag.*NP*1000000;
    for j = 1:nsteps    
        a(j,:)=Mie(m,x(j));
    end;
    b(:,1)=D;
    b(:,2)=a(:,1).*sn;
    b(:,3)=a(:,2).*sn;
    b(:,4)=a(:,3).*sn;
    b(:,5)=a(:,4).*sn;
    b(:,6)=a(:,2).*a(:,5).*sn; 
    gext= sum(b(:,2))*dD;
    gsca= sum(b(:,3))*dD;
    gabs= sum(b(:,4))*dD;
    gb=   sum(b(:,5))*dD;
    gteta=sum(b(:,6))*dD;
    res(jr,:)=[R gext gsca gabs gb gteta];
end; 
d=distribution;
if pam==0
    loglog(res(:,1),res(:,2:5))
    legend('Gext','Gsca','Gabs','Gb')
title(sprintf('Mie Propag. Coeff. at f=%gGHz, T=%gK, Distribution=%s',fGHz,TK,d))
    xlabel('R (mm/h)');    ylabel('Gi(1/km)')
elseif pam==1
    plot(res(:,1),res(:,2:6))
    legend('Gext','Gsca','Gabs','Gb','Gsca*<costeta>')
title(sprintf('Mie Propag. Coeff. at f=%gGHz, T=%gK, Distribution=%s',fGHz,TK,d))
    xlabel('R (mm/h)');    ylabel('Gi(1/km)')
end;
output_parameters='R, Gext, Gsca, Gabs, Gb, Gsca*<costeta>'
result=res;

